"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * The SlugPolicyRouter stores routes in a key-value map.
 *
 * The key is generated like this:
 * `${subject.type}_${resource.type}_${action.type}`
 */
var SlugPolicyRouter = /** @class */ (function () {
    function SlugPolicyRouter(routes) {
        if (routes === void 0) { routes = {}; }
        this.routes = routes;
    }
    SlugPolicyRouter.prototype.route = function (subject, action, resource, handler) {
        var key = subject.type + "_" + resource.type + "_" + action.type;
        this.routes[key] = {
            subject: subject,
            resource: resource,
            action: action,
            handler: handler,
        };
    };
    SlugPolicyRouter.prototype.resolve = function (_a) {
        var subject = _a.subject, action = _a.action, resource = _a.resource;
        var key = this.getKey(subject.type, action.type, resource.type);
        // Resolve policy mapping
        return this.routes[key] || null;
    };
    SlugPolicyRouter.prototype.getKey = function (subject, action, resource) {
        return subject + "_" + resource + "_" + action;
    };
    return SlugPolicyRouter;
}());
exports.SlugPolicyRouter = SlugPolicyRouter;
//# sourceMappingURL=slug-policy-router.js.map